#ifndef NT2_INCLUDE_CONSTANTS_HALF_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_HALF_HPP_INCLUDED

#include <nt2/constant/include/constants/half.hpp>

#endif
